.. vhdl-style-guide documentation master file, created by
   sphinx-quickstart on Sun Dec  3 07:46:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to vhdl-style-guide's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   gallery
   installing
   usage
   formatting_terminal_output
   styles
   configuring
   code_tags
   continuous_integration_servers
   editor_integration/editor_integration
   tool_integration/tool_integration
   pragmas
   localizing
   phases
   rule_severity
   rule_groups
   rules
   contributing
   theory_of_operation/index
   processes/index
   developing/index
   release_notes
